==> teamapps-application-server-0.30-sources.jar: org/teamapps/protocol/system/ApplicationServerProtocol.java <==
package org.teamapps.protocol.system;

import org.teamapps.protocol.schema.*;
import org.teamapps.protocol.service.*;
import org.teamapps.protocol.file.*;
import java.util.HashMap;
import java.util.Map;

public class ApplicationServerProtocol {

	public static final MessageModelCollection MODEL_COLLECTION = new MessageModelCollection("ApplicationServerProtocol", "org.teamapps.protocol.system", 1);


    static {
		ObjectPropertyDefinition systemLogEntry = MODEL_COLLECTION.createModel("systemLogEntry", "#t.sle", 1, null, null);

		systemLogEntry.addProperty("nodeId", 1, PropertyType.LONG, PropertyContentType.GENERIC, null, null);
		systemLogEntry.addProperty("userId", 2, PropertyType.INT, PropertyContentType.GENERIC, null, null);
		systemLogEntry.addProperty("timestamp", 3, PropertyType.LONG, PropertyContentType.GENERIC, null, null);
		systemLogEntry.addProperty("logLevel", 4, PropertyType.INT, PropertyContentType.GENERIC, null, null);
		systemLogEntry.addProperty("managedApplicationId", 5, PropertyType.INT, PropertyContentType.GENERIC, null, null);
		systemLogEntry.addProperty("managedApplicationPerspectiveId", 6, PropertyType.INT, PropertyContentType.GENERIC, null, null);
		systemLogEntry.addProperty("applicationVersion", 7, PropertyType.STRING, PropertyContentType.GENERIC, null, null);
		systemLogEntry.addProperty("exceptionClass", 8, PropertyType.STRING, PropertyContentType.GENERIC, null, null);
		systemLogEntry.addProperty("threadName", 9, PropertyType.STRING, PropertyContentType.GENERIC, null, null);
		systemLogEntry.addProperty("message", 10, PropertyType.STRING, PropertyContentType.GENERIC, null, null);
		systemLogEntry.addProperty("stackTrace", 11, PropertyType.STRING, PropertyContentType.GENERIC, null, null);


		MODEL_COLLECTION.addMessageDecoder(systemLogEntry.getObjectUuid(), SystemLogEntry.getMessageDecoder());

    }



}

==> teamapps-application-server-0.34-sources.jar: org/teamapps/protocol/system/ApplicationServerProtocol.java <==
package org.teamapps.protocol.system;

import org.teamapps.protocol.schema.*;
import org.teamapps.protocol.service.*;
import org.teamapps.protocol.file.*;
import java.util.HashMap;
import java.util.Map;

public class ApplicationServerProtocol {

	public static final MessageModelCollection MODEL_COLLECTION = new MessageModelCollection("ApplicationServerProtocol", "org.teamapps.protocol.system", 1);


    static {
		ObjectPropertyDefinition systemLogEntry = MODEL_COLLECTION.createModel("systemLogEntry", "#t.sle", 1, null, null);

		systemLogEntry.addProperty("nodeId", 1, PropertyType.LONG, PropertyContentType.GENERIC, null, null);
		systemLogEntry.addProperty("userId", 2, PropertyType.INT, PropertyContentType.GENERIC, null, null);
		systemLogEntry.addProperty("timestamp", 3, PropertyType.LONG, PropertyContentType.GENERIC, null, null);
		systemLogEntry.addProperty("logLevel", 4, PropertyType.INT, PropertyContentType.GENERIC, null, null);
		systemLogEntry.addProperty("managedApplicationId", 5, PropertyType.INT, PropertyContentType.GENERIC, null, null);
		systemLogEntry.addProperty("managedApplicationPerspectiveId", 6, PropertyType.INT, PropertyContentType.GENERIC, null, null);
		systemLogEntry.addProperty("applicationVersion", 7, PropertyType.STRING, PropertyContentType.GENERIC, null, null);
		systemLogEntry.addProperty("exceptionClass", 8, PropertyType.STRING, PropertyContentType.GENERIC, null, null);
		systemLogEntry.addProperty("threadName", 9, PropertyType.STRING, PropertyContentType.GENERIC, null, null);
		systemLogEntry.addProperty("title", 10, PropertyType.STRING, PropertyContentType.GENERIC, null, null);
		systemLogEntry.addProperty("message", 11, PropertyType.STRING, PropertyContentType.GENERIC, null, null);
		systemLogEntry.addProperty("stackTrace", 12, PropertyType.STRING, PropertyContentType.GENERIC, null, null);


		MODEL_COLLECTION.addMessageDecoder(systemLogEntry.getObjectUuid(), SystemLogEntry.getMessageDecoder());

    }



}
